@@ -273,12 +273,10 @@ pub(crate) fn prune(dir: &Path, opts: &PruneOptions) -> Result<PruneResults> {
 #[cfg(test)]
 mod tests {
     use super::*;
-    use crate::test::reset;
     use pretty_assertions::assert_eq;
 
     #[test]
     fn test_cache() {
-        reset();
         let cache = CacheManagerBuilder::new(dirs::CACHE.join("test-cache")).build();
         cache.clear().unwrap();
         let val = cache.get_or_try_init(|| Ok(1)).unwrap();
