@@ -125,7 +125,7 @@ impl Env {
     }
 
     fn output_dotenv(&self, config: &Config, ts: Toolset) -> Result<()> {
-        for (k, v) in ts.env(config)? {
+        for (k, v) in ts.final_env(config)?.0 {
             let k = k.to_string();
             let v = v.to_string();
             miseprint!("{}={}\n", k, v)?;
