@@ -362,7 +362,7 @@ impl ConfigFile for MiseToml {
             } else {
                 let mut table = InlineTable::new();
                 table.insert("version", versions[0].version().into());
-                for (k, v) in versions[0].options() {
+                for (k, v) in versions[0].options().opts {
                     table.insert(k, v.into());
                 }
                 tools.insert_formatted(&key, table.into());
@@ -376,7 +376,7 @@ impl ConfigFile for MiseToml {
                 } else {
                     let mut table = InlineTable::new();
                     table.insert("version", v.to_string().into());
-                    for (k, v) in tr.options() {
+                    for (k, v) in tr.options().opts {
                         table.insert(k, v.clone().into());
                     }
                     arr.push(table);
@@ -417,7 +417,7 @@ impl ConfigFile for MiseToml {
             for tool in &tvp.0 {
                 let version = self.parse_template(&tool.tt.to_string())?;
                 let mut tvr = if let Some(mut options) = tool.options.clone() {
-                    for v in options.values_mut() {
+                    for v in options.opts.values_mut() {
                         *v = self.parse_template(v)?;
                     }
                     ToolRequest::new_opts(ba.clone(), &version, options, source.clone())?
@@ -851,7 +851,10 @@ impl<'de> de::Deserialize<'de> for EnvList {
                                     python: venv.python,
                                     uv_create_args: venv.uv_create_args,
                                     python_create_args: venv.python_create_args,
-                                    options: Default::default(),
+                                    options: EnvDirectiveOptions {
+                                        tools: true,
+                                        redact: false,
+                                    },
                                 });
                             }
                         }
@@ -860,7 +863,11 @@ impl<'de> de::Deserialize<'de> for EnvList {
                                 Int(i64),
                                 Str(String),
                                 Bool(bool),
-                                Map { value: Box<Val>, tools: bool },
+                                Map {
+                                    value: Box<Val>,
+                                    tools: bool,
+                                    redact: bool,
+                                },
                             }
                             impl Display for Val {
                                 fn fmt(&self, f: &mut Formatter) -> std::fmt::Result {
@@ -868,11 +875,18 @@ impl<'de> de::Deserialize<'de> for EnvList {
                                         Val::Int(i) => write!(f, "{}", i),
                                         Val::Str(s) => write!(f, "{}", s),
                                         Val::Bool(b) => write!(f, "{}", b),
-                                        Val::Map { value, tools } => {
+                                        Val::Map {
+                                            value,
+                                            tools,
+                                            redact,
+                                        } => {
                                             write!(f, "{}", value)?;
                                             if *tools {
                                                 write!(f, " tools")?;
                                             }
+                                            if *redact {
+                                                write!(f, " redact")?;
+                                            }
                                             Ok(())
                                         }
                                     }
@@ -926,6 +940,7 @@ impl<'de> de::Deserialize<'de> for EnvList {
                                         {
                                             let mut value: Option<Val> = None;
                                             let mut tools = None;
+                                            let mut redact = None;
                                             while let Some((key, val)) =
                                                 map.next_entry::<String, Val>()?
                                             {
@@ -936,10 +951,13 @@ impl<'de> de::Deserialize<'de> for EnvList {
                                                     "tools" => {
                                                         tools = Some(val);
                                                     }
+                                                    "redact" => {
+                                                        redact = Some(val);
+                                                    }
                                                     _ => {
                                                         return Err(de::Error::unknown_field(
                                                             &key,
-                                                            &["value", "tools"],
+                                                            &["value", "tools", "redact"],
                                                         ));
                                                     }
                                                 }
@@ -954,6 +972,15 @@ impl<'de> de::Deserialize<'de> for EnvList {
                                             Ok(Val::Map {
                                                 value: Box::new(value),
                                                 tools,
+                                                redact: redact
+                                                    .map(|r| {
+                                                        if let Val::Bool(b) = r {
+                                                            b
+                                                        } else {
+                                                            false
+                                                        }
+                                                    })
+                                                    .unwrap_or_default(),
                                             })
                                         }
                                     }
@@ -982,8 +1009,12 @@ impl<'de> de::Deserialize<'de> for EnvList {
                                 Val::Bool(false) => {
                                     env.push(EnvDirective::Rm(key, Default::default()))
                                 }
-                                Val::Map { value, tools } => {
-                                    let opts = EnvDirectiveOptions { tools };
+                                Val::Map {
+                                    value,
+                                    tools,
+                                    redact,
+                                } => {
+                                    let opts = EnvDirectiveOptions { tools, redact };
                                     env.push(EnvDirective::Val(key, value.to_string(), opts));
                                 }
                             }
@@ -1040,7 +1071,7 @@ impl<'de> de::Deserialize<'de> for MiseTomlToolList {
             where
                 M: de::MapAccess<'de>,
             {
-                let mut options: BTreeMap<String, String> = Default::default();
+                let mut options: ToolVersionOptions = Default::default();
                 let mut os: Option<Vec<String>> = None;
                 let mut tt: Option<ToolVersionType> = None;
                 while let Some((k, v)) = map.next_entry::<String, toml::Value>()? {
@@ -1062,21 +1093,44 @@ impl<'de> de::Deserialize<'de> for MiseTomlToolList {
                                 );
                             }
                             toml::Value::String(s) => {
-                                options.insert(k, s);
+                                options.opts.insert(k, s);
                             }
                             _ => {
                                 return Err(de::Error::custom("os must be a string or array"));
                             }
                         },
+                        "install_env" => match v {
+                            toml::Value::Table(env) => {
+                                for (k, v) in env {
+                                    match v {
+                                        toml::Value::Boolean(v) => {
+                                            options.env.insert(k, v.to_string());
+                                        }
+                                        toml::Value::Integer(v) => {
+                                            options.env.insert(k, v.to_string());
+                                        }
+                                        toml::Value::String(v) => {
+                                            options.env.insert(k, v);
+                                        }
+                                        _ => {
+                                            return Err(de::Error::custom("invalid value type"));
+                                        }
+                                    }
+                                }
+                            }
+                            _ => {
+                                return Err(de::Error::custom("env must be a table"));
+                            }
+                        },
                         _ => match v {
                             toml::Value::Boolean(v) => {
-                                options.insert(k, v.to_string());
+                                options.opts.insert(k, v.to_string());
                             }
                             toml::Value::Integer(v) => {
-                                options.insert(k, v.to_string());
+                                options.opts.insert(k, v.to_string());
                             }
                             toml::Value::String(v) => {
-                                options.insert(k, v);
+                                options.opts.insert(k, v);
                             }
                             _ => {
                                 return Err(de::Error::custom("invalid value type"));
@@ -1142,12 +1196,15 @@ impl<'de> de::Deserialize<'de> for MiseTomlEnvDirective {
                 let mut value = None;
                 while let Some((k, v)) = map.next_entry::<String, toml::Value>()? {
                     match k.as_str() {
-                        "value" => {
+                        "value" | "path" => {
                             value = Some(v.as_str().unwrap().to_string());
                         }
                         "tools" => {
                             options.tools = v.as_bool().unwrap();
                         }
+                        "redact" => {
+                            options.redact = v.as_bool().unwrap();
+                        }
                         _ => {
                             return Err(de::Error::custom("invalid key"));
                         }
@@ -1196,7 +1253,7 @@ impl<'de> de::Deserialize<'de> for MiseTomlTool {
             where
                 M: de::MapAccess<'de>,
             {
-                let mut options: BTreeMap<String, String> = Default::default();
+                let mut options: ToolVersionOptions = Default::default();
                 let mut os: Option<Vec<String>> = None;
                 let mut tt = ToolVersionType::System;
                 while let Some((k, v)) = map.next_entry::<String, toml::Value>()? {
@@ -1216,14 +1273,37 @@ impl<'de> de::Deserialize<'de> for MiseTomlTool {
                                 );
                             }
                             toml::Value::String(s) => {
-                                options.insert(k, s);
+                                options.opts.insert(k, s);
                             }
                             _ => {
                                 return Err(de::Error::custom("os must be a string or array"));
                             }
                         },
+                        "install_env" => match v {
+                            toml::Value::Table(env) => {
+                                for (k, v) in env {
+                                    match v {
+                                        toml::Value::Boolean(v) => {
+                                            options.env.insert(k, v.to_string());
+                                        }
+                                        toml::Value::Integer(v) => {
+                                            options.env.insert(k, v.to_string());
+                                        }
+                                        toml::Value::String(v) => {
+                                            options.env.insert(k, v);
+                                        }
+                                        _ => {
+                                            return Err(de::Error::custom("invalid value type"));
+                                        }
+                                    }
+                                }
+                            }
+                            _ => {
+                                return Err(de::Error::custom("env must be a table"));
+                            }
+                        },
                         _ => {
-                            options.insert(k, v.as_str().unwrap().to_string());
+                            options.opts.insert(k, v.as_str().unwrap().to_string());
                         }
                     }
                 }
