@@ -409,7 +409,15 @@ impl Config {
             task.config_source = path.to_path_buf();
             task.config_root = Some(config_root.to_path_buf());
         }
-        Ok(tasks.into_values().collect())
+        Ok(tasks
+            .into_values()
+            .map(|mut t| {
+                if let Err(err) = t.render(config_root) {
+                    warn!("rendering task: {err:?}");
+                }
+                t
+            })
+            .collect())
     }
 
     fn load_local_tasks(&self) -> Result<Vec<Task>> {
@@ -909,7 +917,10 @@ pub fn load_config_paths(config_filenames: &[String], include_ignored: bool) ->
     config_files
         .into_iter()
         .unique_by(|p| file::desymlink_path(p))
-        .filter(|p| include_ignored || !config_file::is_ignored(&config_trust_root(p)))
+        .filter(|p| {
+            include_ignored
+                || !(config_file::is_ignored(&config_trust_root(p)) || config_file::is_ignored(p))
+        })
         .collect()
 }
 
