@@ -114,6 +114,8 @@ pub static MISE_GLOBAL_CONFIG_FILE: Lazy<PathBuf> = Lazy::new(|| {
         .or_else(|| var_path("MISE_CONFIG_FILE"))
         .unwrap_or_else(|| MISE_CONFIG_DIR.join("config.toml"))
 });
+pub static MISE_GLOBAL_CONFIG_ROOT: Lazy<PathBuf> =
+    Lazy::new(|| var_path("MISE_GLOBAL_CONFIG_ROOT").unwrap_or_else(|| HOME.to_path_buf()));
 pub static MISE_SYSTEM_CONFIG_FILE: Lazy<PathBuf> = Lazy::new(|| {
     var_path("MISE_SYSTEM_CONFIG_FILE").unwrap_or_else(|| MISE_SYSTEM_DIR.join("config.toml"))
 });
