@@ -2,14 +2,16 @@ use std::collections::BTreeMap;
 use std::ffi::OsString;
 use std::fmt::Debug;
 use std::io::prelude::*;
+use std::iter::once;
 use std::path::{Path, PathBuf};
 
 use base64::prelude::*;
 use eyre::Result;
 use flate2::write::{ZlibDecoder, ZlibEncoder};
 use flate2::Compression;
-use indexmap::IndexMap;
+use indexmap::{IndexMap, IndexSet};
 use itertools::Itertools;
+use once_cell::sync::Lazy;
 use serde_derive::{Deserialize, Serialize};
 
 use crate::env::PATH_KEY;
@@ -60,7 +62,12 @@ impl EnvDiff {
         diff
     }
 
-    pub fn from_bash_script<T, U, V>(script: &Path, dir: &Path, env: T) -> Result<Self>
+    pub fn from_bash_script<T, U, V>(
+        script: &Path,
+        dir: &Path,
+        env: T,
+        opts: EnvDiffOptions,
+    ) -> Result<Self>
     where
         T: IntoIterator<Item = (U, V)>,
         U: Into<OsString>,
@@ -92,7 +99,7 @@ impl EnvDiff {
             match line.strip_prefix("declare -x ") {
                 Some(line) => {
                     let (k, v) = line.split_once('=').unwrap_or_default();
-                    if valid_key(k) {
+                    if invalid_key(k, &opts) {
                         continue;
                     }
                     cur_key = Some(k.to_string());
@@ -161,20 +168,9 @@ impl EnvDiff {
     }
 }
 
-fn valid_key(k: &str) -> bool {
+fn invalid_key(k: &str, opts: &EnvDiffOptions) -> bool {
     k.is_empty()
-        || k == "_"
-        || k == "SHLVL"
-        || k == *PATH_KEY
-        || k == "PWD"
-        || k == "OLDPWD"
-        || k == "HOME"
-        || k == "USER"
-        || k == "SHELL"
-        || k == "SHELLOPTS"
-        || k == "COMP_WORDBREAKS"
-        || k == "PS1"
-        || k == "PROMPT_DIRTRIM"
+        || opts.ignore_keys.contains(k)
         // following two ignores are for exported bash functions and exported bash
         // functions which are multiline, they appear in the environment as e.g.:
         // BASH_FUNC_exported-bash-function%%=() { echo "this is an"
@@ -185,6 +181,25 @@ fn valid_key(k: &str) -> bool {
         || k.starts_with(' ')
 }
 
+static DEFAULT_IGNORE_KEYS: Lazy<IndexSet<String>> = Lazy::new(|| {
+    [
+        "_",
+        "SHLVL",
+        "PWD",
+        "OLDPWD",
+        "HOME",
+        "USER",
+        "SHELL",
+        "SHELLOPTS",
+        "COMP_WORDBREAKS",
+        "PS1",
+        "PROMPT_DIRTRIM",
+    ]
+    .iter()
+    .map(|s| s.to_string())
+    .collect()
+});
+
 impl Debug for EnvDiff {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         let print_sorted = |hashmap: &IndexMap<String, String>| {
@@ -248,6 +263,22 @@ fn normalize_escape_sequences(input: &str) -> String {
     result
 }
 
+pub struct EnvDiffOptions {
+    pub ignore_keys: IndexSet<String>,
+}
+
+impl Default for EnvDiffOptions {
+    fn default() -> Self {
+        Self {
+            ignore_keys: DEFAULT_IGNORE_KEYS
+                .iter()
+                .cloned()
+                .chain(once(PATH_KEY.to_string()))
+                .collect(),
+        }
+    }
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
@@ -356,7 +387,7 @@ mod tests {
             .map(|(k, v)| (k.into(), v.into()))
             .collect::<Vec<(String, String)>>();
         let cwd = dirs::CWD.clone().unwrap();
-        let ed = EnvDiff::from_bash_script(path.as_path(), &cwd, orig).unwrap();
+        let ed = EnvDiff::from_bash_script(path.as_path(), &cwd, orig, Default::default()).unwrap();
         assert_debug_snapshot!(ed);
     }
 
