@@ -15,12 +15,12 @@ use serde_derive::{Deserialize, Serialize};
 
 use crate::config::Config;
 use crate::env::PATH_KEY;
-use crate::env_diff::{EnvDiffOperation, EnvDiffPatches};
+use crate::env_diff::{EnvDiffOperation, EnvDiffPatches, EnvMap};
 use crate::hash::hash_to_str;
 use crate::shell::Shell;
 use crate::{dirs, env, hooks, watch_files};
 
-pub static CUR_SESSION: Lazy<HookEnvSession> = Lazy::new(|| {
+pub static PREV_SESSION: Lazy<HookEnvSession> = Lazy::new(|| {
     env::var("__MISE_SESSION")
         .ok()
         .and_then(|s| {
@@ -80,7 +80,7 @@ pub fn should_exit_early(watch_files: impl IntoIterator<Item = WatchFilePattern>
 }
 
 pub fn dir_change() -> Option<(Option<PathBuf>, PathBuf)> {
-    match (&CUR_SESSION.dir, &*dirs::CWD) {
+    match (&PREV_SESSION.dir, &*dirs::CWD) {
         (Some(old), Some(new)) if old != new => {
             trace!("dir change: {:?} -> {:?}", old, new);
             Some((Some(old.clone()), new.clone()))
@@ -94,6 +94,10 @@ pub fn dir_change() -> Option<(Option<PathBuf>, PathBuf)> {
 }
 
 fn have_files_been_modified(watch_files: BTreeSet<PathBuf>) -> bool {
+    if let Some(p) = PREV_SESSION.loaded_configs.iter().find(|p| !p.exists()) {
+        trace!("config deleted: {}", p.display());
+        return true;
+    }
     // check the files to see if they've been altered
     let mut modified = false;
     for fp in &watch_files {
@@ -102,7 +106,7 @@ fn have_files_been_modified(watch_files: BTreeSet<PathBuf>) -> bool {
                 .duration_since(SystemTime::UNIX_EPOCH)
                 .unwrap()
                 .as_millis();
-            if modtime > CUR_SESSION.latest_update {
+            if modtime > PREV_SESSION.latest_update {
                 trace!("file modified: {:?}", fp);
                 modified = true;
                 watch_files::add_modified_file(fp.clone());
@@ -116,7 +120,7 @@ fn have_files_been_modified(watch_files: BTreeSet<PathBuf>) -> bool {
 }
 
 fn have_mise_env_vars_been_modified() -> bool {
-    if get_mise_env_vars_hashed() != CUR_SESSION.env_var_hash {
+    if get_mise_env_vars_hashed() != PREV_SESSION.env_var_hash {
         return true;
     }
     false
@@ -127,6 +131,7 @@ pub struct HookEnvSession {
     pub loaded_tools: IndexSet<String>,
     pub loaded_configs: IndexSet<PathBuf>,
     pub config_paths: IndexSet<PathBuf>,
+    pub env: EnvMap,
     dir: Option<PathBuf>,
     env_var_hash: String,
     latest_update: u128,
@@ -148,7 +153,9 @@ pub fn deserialize<T: serde::de::DeserializeOwned>(raw: String) -> Result<T> {
 }
 
 pub fn build_session(
-    watch_files: impl IntoIterator<Item = WatchFilePattern>,
+    env: EnvMap,
+    loaded_tools: IndexSet<String>,
+    watch_files: BTreeSet<WatchFilePattern>,
 ) -> Result<HookEnvSession> {
     let config = Config::get();
     let mut max_modtime = UNIX_EPOCH;
@@ -167,13 +174,9 @@ pub fn build_session(
     Ok(HookEnvSession {
         dir: dirs::CWD.clone(),
         env_var_hash: get_mise_env_vars_hashed(),
+        env,
         loaded_configs: config.config_files.keys().cloned().collect(),
-        loaded_tools: config
-            .get_toolset()?
-            .list_current_versions()
-            .into_iter()
-            .map(|(_, tv)| tv.to_string())
-            .collect(),
+        loaded_tools,
         config_paths,
         latest_update: max_modtime
             .duration_since(SystemTime::UNIX_EPOCH)
