@@ -12,10 +12,6 @@ fn init() {
     }
     console::set_colors_enabled(false);
     console::set_colors_enabled_stderr(false);
-    if env::var("__MISE_DIFF").is_ok() {
-        // TODO: fix this
-        panic!("cannot run tests when mise is activated");
-    }
     env::set_var(
         "HOME",
         PathBuf::from(env!("CARGO_MANIFEST_DIR")).join("test"),
