@@ -52,6 +52,9 @@ impl MiseTable {
         table
             .load_preset(comfy_table::presets::NOTHING)
             .set_content_arrangement(ContentArrangement::Dynamic);
+        if console::colors_enabled() {
+            table.enforce_styling();
+        }
         if !no_header && console::user_attended() {
             let headers = headers.iter().map(Self::header).collect_vec();
             table.set_header(headers);
